pub struct PerfConfig {
pub model_ids: Vec<i64>,
pub pp_tokens: u32,
pub tg_tokens: u32,
pub repetitions: u32,
}Expand description
Configuration for a performance (llama-bench) run.
Fields
model_ids: Vec<i64>Models to benchmark (by database ID), run sequentially.
pp_tokens: u32Number of prompt tokens to use in the benchmark.
tg_tokens: u32Number of generation tokens to use in the benchmark.
repetitions: u32Number of repetitions to average.
Implementations
Sourceimpl PerfConfig
impl PerfConfig
const fn default_pp_tokens() -> u32
const fn default_tg_tokens() -> u32
const fn default_repetitions() -> u32